inputgraph

package
v0.8.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: MPL-2.0 Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FormatError

func FormatError(err error) string

FormatError looks for a wrapped instance of Error in the error list. If one is found, it will prefix the error message with source file information associated with the error.

func ParseProjectCommand

func ParseProjectCommand(
	ctx context.Context, target domain.Target, console conslogging.ConsoleLogger,
) (string, string, error)

Types

type Error

type Error struct {
	// contains filtered or unexported fields
}

Error represents an auto-skip error that can include the source file name and associated line number.

func (*Error) Error

func (e *Error) Error() string

Error implements [error] interface.

type HashOpt

type HashOpt struct {
	OverridingVars *variables.Scope
	Target         domain.Target
	BuiltinArgs    variables.DefaultArgs
	Console        conslogging.ConsoleLogger
	CI             bool
}

HashOpt contains all of the options available to the hasher.

type Stats

type Stats struct {
	StartTime       time.Time
	TargetsHashed   int
	TargetCacheHits int
	TargetsVisited  int
	Duration        time.Duration
}

Stats contains some statistics about the hashing process.

func HashTarget

func HashTarget(ctx context.Context, opt HashOpt) ([]byte, Stats, error)

HashTarget produces a hash from an Earthly target.

Jump to