formatter

package
v0.8.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: MPL-2.0 Imports: 21 Imported by: 0

Documentation

Index

Constants

const (

	// BuildkitStatsStream is the stream number associated with runc stats.
	BuildkitStatsStream = 99 // TODO move to a common location in buildkit
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Formatter

type Formatter struct {
	// contains filtered or unexported fields
}

Formatter is a delta to console logger.

func New

func New(
	ctx context.Context,
	b *logbus.Bus,
	debug, verbose, displayStats, forceColor, noColor, disableOngoingUpdates bool,
	execStatsTracker *execstatssummary.Tracker,
	isGitHubActions bool,
) *Formatter

New creates a new Formatter.

func (*Formatter) Close

func (f *Formatter) Close() error

Close stops the formatter and returns any errors encountered during formatting.

func (*Formatter) Manifest

func (f *Formatter) Manifest() *logstream.RunManifest

Manifest returns a copy of the manifest.

func (*Formatter) SetDefaultPlatform

func (f *Formatter) SetDefaultPlatform(platform string)

SetDefaultPlatform sets the default platform.

func (*Formatter) Write

func (f *Formatter) Write(delta *logstream.Delta)

Write writes a delta to the console.

Jump to