setup

package
v0.8.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: MPL-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BusSetup

type BusSetup struct {
	Bus             *logbus.Bus
	ConsoleWriter   *writersub.WriterSub
	Formatter       *formatter.Formatter
	SolverMonitor   *solvermon.SolverMonitor
	BusDebugWriter  *writersub.RawWriterSub
	InitialManifest *logstream.RunManifest
	// contains filtered or unexported fields
}

BusSetup is a helper for setting up a logbus.Bus.

func New

func New(
	ctx context.Context,
	bus *logbus.Bus,
	debug, verbose, displayStats, forceColor, noColor, disableOngoingUpdates bool,
	busDebugFile, buildID string,
	execStatsTracker *execstatssummary.Tracker,
	isGitHubActions bool,
) (*BusSetup, error)

New creates a new BusSetup.

func (*BusSetup) Close

func (bs *BusSetup) Close(ctx context.Context) error

Close the bus setup & gather all errors.

func (*BusSetup) DumpManifestToFile

func (bs *BusSetup) DumpManifestToFile(path string) error

DumpManifestToFile dumps the manifest to the given file.

func (*BusSetup) SetCI

func (bs *BusSetup) SetCI(isCI bool)

SetCI tracks whether this build is being run in a CI environment.

func (*BusSetup) SetDefaultPlatform

func (bs *BusSetup) SetDefaultPlatform(platform string)

SetDefaultPlatform sets the default platform of the build.

func (*BusSetup) SetGitAuthor

func (bs *BusSetup) SetGitAuthor(gitAuthor, gitCommitEmail string)

SetGitAuthor records the Git author information on the initial manifest.

Jump to