Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type VertexMeta ¶
type VertexMeta struct {
SourceLocation *spec.SourceLocation `json:"sl,omitempty"`
OverridingArgs map[string]string `json:"args,omitempty"`
CommandID string `json:"cid,omitempty"`
RepoGitURL string `json:"rgu,omitempty"`
RepoGitHash string `json:"rgh,omitempty"`
TargetID string `json:"tid,omitempty"`
TargetName string `json:"tnm,omitempty"`
CanonicalTargetName string `json:"ctnm,omitempty"`
Platform string `json:"plt,omitempty"`
Runner string `json:"runner,omitempty"`
RepoFileRelToRepo string `json:"rfr,omitempty"`
Secrets []string `json:"secrets,omitempty"`
Interactive bool `json:"itrctv,omitempty"`
Local bool `json:"lcl,omitempty"`
Internal bool `json:"itrnl,omitempty"`
NonDefaultPlatform bool `json:"defplt,omitempty"`
}
VertexMeta is metadata associated with the vertex. This is passed from the converter to the solver monitor via BuildKit.
func ParseFromVertexPrefix ¶
func ParseFromVertexPrefix(in string) (*VertexMeta, string)
ParseFromVertexPrefix parses the vertex prefix from the given string.
func (*VertexMeta) OverridingArgsString ¶
func (vm *VertexMeta) OverridingArgsString() string
OverridingArgsString returns the string representation of the overriding arguments.
func (*VertexMeta) Salt ¶
func (vm *VertexMeta) Salt() string
Salt returns a string identifying the target as uniquely as possible.
func (*VertexMeta) SecretsString ¶
func (vm *VertexMeta) SecretsString() string
SecretsString returns the string representation of the secrets. It will only include the names of secrets, no values.
func (*VertexMeta) ToVertexPrefix ¶
func (vm *VertexMeta) ToVertexPrefix() string
ToVertexPrefix returns the vertex prefix for the given VertexMeta.
Click to show internal directories.
Click to hide internal directories.