package
Version:
v0.8.17
Opens a new window with list of versions in this module.
Published: Feb 11, 2026
License: MPL-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
WaitBlock stores items within a WAIT / END block.
type WaitItem interface {
SetDoPush()
SetDoSave()
}
WaitItem is an item to wait for.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.