Documentation
¶
Index ¶
- Constants
- func IsValidEnvVarName(name string) bool
- func Parse(filePath string, enableSourceMap bool) (ef spec.Earthfile, err error)
- func ParseOpts(from FromOpt, opts ...Opt) (spec.Earthfile, error)
- func ParseVersion(filePath string, enableSourceMap bool) (*spec.Version, error)
- func ParseVersionOpts(fromOpt FromOpt, opts ...Opt) (*spec.Version, error)
- type FromOpt
- type NamedReader
- type Opt
Constants ¶
const TargetBase = "base"
Variables ¶
This section is empty.
Functions ¶
func IsValidEnvVarName ¶
IsValidEnvVarName returns true if env name is valid.
func ParseOpts ¶
ParseOpts parses an earthfile into an AST. This is the functional option version, which uses option functions to change how a file is parsed.
func ParseVersion ¶
ParseVersion reads the VERSION command for an Earthfile and returns spec.Version.
Types ¶
type FromOpt ¶
type FromOpt func(prefs) (prefs, error)
FromOpt is an option function for customizing the source reader of ParseVersion.
func FromReader ¶
func FromReader(r NamedReader) FromOpt
FromReader tells ParseVersion to read from reader.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.