Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatError ¶
FormatError looks for a wrapped instance of Error in the error list. If one is found, it will prefix the error message with source file information associated with the error.
func ParseProjectCommand ¶
func ParseProjectCommand( ctx context.Context, target domain.Target, console conslogging.ConsoleLogger, ) (string, string, error)
Types ¶
type Error ¶
type Error struct {
// contains filtered or unexported fields
}
Error represents an auto-skip error that can include the source file name and associated line number.
type HashOpt ¶
type HashOpt struct {
OverridingVars *variables.Scope
Target domain.Target
BuiltinArgs variables.DefaultArgs
Console conslogging.ConsoleLogger
CI bool
}
HashOpt contains all of the options available to the hasher.
Click to show internal directories.
Click to hide internal directories.