Documentation
¶
Index ¶
Constants ¶
const ( // BuildkitStatsStream is the stream number associated with runc stats. BuildkitStatsStream = 99 // TODO move to a common location in buildkit )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Formatter ¶
type Formatter struct {
// contains filtered or unexported fields
}
Formatter is a delta to console logger.
func New ¶
func New( ctx context.Context, b *logbus.Bus, debug, verbose, displayStats, forceColor, noColor, disableOngoingUpdates bool, execStatsTracker *execstatssummary.Tracker, isGitHubActions bool, ) *Formatter
New creates a new Formatter.
func (*Formatter) Close ¶
Close stops the formatter and returns any errors encountered during formatting.
func (*Formatter) Manifest ¶
func (f *Formatter) Manifest() *logstream.RunManifest
Manifest returns a copy of the manifest.
func (*Formatter) SetDefaultPlatform ¶
SetDefaultPlatform sets the default platform.
Click to show internal directories.
Click to hide internal directories.