Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BusSetup ¶
type BusSetup struct {
Bus *logbus.Bus
ConsoleWriter *writersub.WriterSub
Formatter *formatter.Formatter
SolverMonitor *solvermon.SolverMonitor
BusDebugWriter *writersub.RawWriterSub
InitialManifest *logstream.RunManifest
// contains filtered or unexported fields
}
BusSetup is a helper for setting up a logbus.Bus.
func New ¶
func New( ctx context.Context, bus *logbus.Bus, debug, verbose, displayStats, forceColor, noColor, disableOngoingUpdates bool, busDebugFile, buildID string, execStatsTracker *execstatssummary.Tracker, isGitHubActions bool, ) (*BusSetup, error)
New creates a new BusSetup.
func (*BusSetup) DumpManifestToFile ¶
DumpManifestToFile dumps the manifest to the given file.
func (*BusSetup) SetDefaultPlatform ¶
SetDefaultPlatform sets the default platform of the build.
func (*BusSetup) SetGitAuthor ¶
SetGitAuthor records the Git author information on the initial manifest.
Click to show internal directories.
Click to hide internal directories.